.. _listeners:

Listeners
#########

Redis
=====

.. autoclass:: cliquet.listeners.redis.RedisListener

API
===

Implementing a custom notification listener consists on implementing the
following interface:

.. autoclass:: cliquet.listeners.ListenerBase
    :members:

